<?php

/**
 * @file
 * Class Qwantsearch.
 */

/**
 * Class Qwantsearch.
 */
class Qwantsearch {

  /**
   * Qwant search endpoint.
   *
   * @var string
   */
  private static $endpoint = 'https://api.qwant.com/partners/!partner_id/search';

  /**
   * Qwant http token.
   *
   * @var string
   */
  public $httpToken;

  /**
   * Qwant partner id.
   *
   * @var string
   */
  public $partnerId;

  /**
   * Qwantsearch constructor.
   *
   * @param string $httpToken
   *   Http token provided by Qwant.
   * @param string $partnerId
   *   Partner ID provided by Qwant.
   */
  public function __construct($httpToken, $partnerId) {
    $this->httpToken = $httpToken;
    $this->partnerId = $partnerId;
  }

  /**
   * Makes a query to qwant using given httpToken, partner_id and query_text.
   *
   * @param array $params
   *   Parameters for the query.
   *
   * @return object
   *   Object returned by drupal_http_request.
   */
  public function makeQuery(array $params = array()) {
    $httpOptions = array(
      'headers' => array(
        'token' => $this->httpToken,
      ),
    );

    $params += array(
      'q' => ' ',
      'offset' => 0,
      'count' => 10,
      'f' => 'order:relevance',
    );

    $endpoint = str_replace('!partner_id', $this->partnerId, self::$endpoint);
    $getParams = drupal_http_build_query($params);
    $response = drupal_http_request($endpoint . '?' . $getParams, $httpOptions);

    return $response;

  }

  /**
   * Parses drupal_http_request response.
   *
   * @param object $response
   *   Query response.
   *
   * @return array
   *   Response from Qwant transformed into array using drupal_json_decode.
   *   Contains response status, results...
   */
  public function parseResponse($response) {
    $responseData = array(
      'status' => 'failure',
    );

    $jsonResponse = $response->data;
    if (!empty($jsonResponse)) {
      $responseData = drupal_json_decode($jsonResponse);
    }

    return $responseData;
  }

  /**
   * Return TRUE if status is a success.
   *
   * @param array $response
   *   Response returned by makeQuery.
   *
   * @return bool
   *   TRUE if request succeeded, FALSE otherwise.
   */
  public function isSuccess(array $response) {
    return $response['status'] == 'success';
  }

}
